# civic_scraper.platforms.civic_plus package

## Submodules

## civic_scraper.platforms.civic_plus.parser module

```{eval-rst}
.. automodule:: civic_scraper.platforms.civic_plus.parser
   :members:
   :undoc-members:
   :show-inheritance:
```

## civic_scraper.platforms.civic_plus.site module

```{eval-rst}
.. automodule:: civic_scraper.platforms.civic_plus.site
   :members:
   :undoc-members:
   :show-inheritance:
```

## Module contents

```{eval-rst}
.. automodule:: civic_scraper.platforms.civic_plus
   :members:
   :undoc-members:
   :show-inheritance:
```
